@@ -392,7 +392,7 @@ from ae.core import DEBUG_LEVELS, registered_app_names
 from ae.console import ConsoleApp                                                                       # type: ignore
 
 
-__version__ = '0.1.71'
+__version__ = '0.1.72'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -1443,8 +1443,22 @@ class MainAppBase(ConsoleApp, ABC):
 
         :param win_pos_size:    window geometry/coordinates: x, y, width, height.
         """
-        self.framework_app.landscape = win_pos_size[2] >= win_pos_size[3]
-        self.vpo(f"MainAppBase.win_pos_size_change landscape={self.framework_app.landscape}, {win_pos_size}")
+        app = self.framework_app
+        win_width, win_height = win_pos_size[2:]
+
+        app.landscape = win_width >= win_height                 # update landscape flag
+
+        min_len = min(win_width, win_height)
+        font_size = self.font_size
+        max_f = min(round(min_len / 24.6), MAX_FONT_SIZE)
+        min_f = max(round(min_len / 48.9), MIN_FONT_SIZE)
+        if not min_f <= font_size <= max_f:
+            self.change_app_state('font_size', min(max(min_f, font_size), max_f))
+        app.max_font_size = max_f                               # update dynamic min/max font size
+        app.min_font_size = min_f
+
+        self.vpo(f"MainAppBase.win_pos_size_change {win_pos_size}: landscape={app.landscape} font size={min_f}-{max_f}")
+
         self.change_app_state('win_rectangle', win_pos_size)
         self.call_method('on_win_pos_size')
 
